==> alliance-5.0-20020701.tar.gz: alliance-5.0/lynx/src/lynxrcn.h <==
/*------------------------------------------------------------\
|                                                             |
| This file is part of the Alliance CAD System Copyright      |
| (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
|                                                             |
| Home page      : http://www-asim.lip6.fr/alliance/          |
| E-mail support : mailto:alliance-support@asim.lip6.fr       |
|                                                             |
| This progam is  free software; you can redistribute it      |
| and/or modify it under the  terms of the GNU General Public |
| License as  published by the Free Software Foundation;      |
| either version 2 of the License, or (at your option) any    |
| later version.                                              |
|                                                             |
| Alliance VLSI  CAD System  is distributed  in the hope that |
| it  will be useful, but WITHOUT  ANY WARRANTY;              |
| without even the  implied warranty of MERCHANTABILITY or    |
| FITNESS FOR A PARTICULAR PURPOSE. See the GNU General       |
| Public License for more details.                            |
|                                                             |
| You should have received a copy  of the GNU General Public  |
| License along with the GNU C Library; see the file COPYING. |
| If not, write to the Free Software Foundation, Inc.,        |
| 675 Mass Ave, Cambridge, MA 02139, USA.                     |
|                                                             |
\------------------------------------------------------------*/

/*************************************************************
*                                                            *
*                                                            *
* Changed by:    Greg                                        *
* Date:          10/07/95                                    *
* New file:      .                                           *
* Comments:                                                  *
* -Fichier des variables globales a verifier.                *
* -                                                          *
* -                                                          *
* -                                                          *
*************************************************************/

#define RCN_FEQUI   ((long)1972)
#define LYNX_DUMP   ((long)1973)
#define RDSLOCON1   ((long)1974)     /* Connecteur provenant de la figure */
#define RDSLOCON2   ((long)1975)     /* Connecteur provenant des instances */
#define RDSLOCON3   ((long)1976)     /* Connecteur provenant d'un transistor */
#define RDSLOCON    ((long)1977)     /* Identificateur de LOCON dans la ptype d'un records */
#define GRGVIA      ((long)1978)     /* Ident de regroupement des vias */
#define INTER_PERPEN  ((long)1979) 
#define INTER_PARAL  ((long)1980) 
#define TMPLONODE    ((long)1981)
#define RDSSIGNAL   ((long)1982)     /* Signal associe a un rectangle */
#define RCN_SIG_PTR ((long)1984)

==> alliance-5.0-20110203.tar.gz: alliance-5.0/lynx/src/lynxrcn.h <==
/*------------------------------------------------------------\
|                                                             |
| This file is part of the Alliance CAD System Copyright      |
| (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
|                                                             |
| Home page      : http://www-asim.lip6.fr/alliance/          |
| E-mail         : mailto:alliance-users@asim.lip6.fr       |
|                                                             |
| This progam is  free software; you can redistribute it      |
| and/or modify it under the  terms of the GNU General Public |
| License as  published by the Free Software Foundation;      |
| either version 2 of the License, or (at your option) any    |
| later version.                                              |
|                                                             |
| Alliance VLSI  CAD System  is distributed  in the hope that |
| it  will be useful, but WITHOUT  ANY WARRANTY;              |
| without even the  implied warranty of MERCHANTABILITY or    |
| FITNESS FOR A PARTICULAR PURPOSE. See the GNU General       |
| Public License for more details.                            |
|                                                             |
| You should have received a copy  of the GNU General Public  |
| License along with the GNU C Library; see the file COPYING. |
| If not, write to the Free Software Foundation, Inc.,        |
| 675 Mass Ave, Cambridge, MA 02139, USA.                     |
|                                                             |
\------------------------------------------------------------*/

/*************************************************************
*                                                            *
*                                                            *
* Changed by:    Greg                                        *
* Date:          10/07/95                                    *
* New file:      .                                           *
* Comments:                                                  *
* -Fichier des variables globales a verifier.                *
* -                                                          *
* -                                                          *
* -                                                          *
*************************************************************/

#define RCN_FEQUI   ((long)1972)
#define LYNX_DUMP   ((long)1973)
#define RDSLOCON1   ((long)1974)     /* Connecteur provenant de la figure */
#define RDSLOCON2   ((long)1975)     /* Connecteur provenant des instances */
#define RDSLOCON3   ((long)1976)     /* Connecteur provenant d'un transistor */
#define RDSLOCON    ((long)1977)     /* Identificateur de LOCON dans la ptype d'un records */
#define GRGVIA      ((long)1978)     /* Ident de regroupement des vias */
#define INTER_PERPEN  ((long)1979) 
#define INTER_PARAL  ((long)1980) 
#define TMPLONODE    ((long)1981)
#define RDSSIGNAL   ((long)1982)     /* Signal associe a un rectangle */
#define RCN_SIG_PTR ((long)1984)
